@@ -1,5 +1,5 @@
 # -*- perl -*-
-# $Id: RobotUA.pm,v 1.5 2000/04/20 14:49:17 langhein Exp $
+# $Id: RobotUA.pm,v 1.6 2001/02/21 11:11:24 langhein Exp $
 # derived from: RobotUA.pm,v 1.15 1999/03/20 07:37:36 gisle Exp $
 
 
@@ -8,7 +8,7 @@ package LWP::Parallel::RobotUA;
 use LWP::Parallel::UserAgent qw(:CALLBACK);
 require LWP::RobotUA;
 @ISA = qw(LWP::Parallel::UserAgent LWP::RobotUA Exporter);
-$VERSION = sprintf("%d.%02d", q$Revision: 1.5 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 1.6 $ =~ /(\d+)\.(\d+)/);
 
 @EXPORT = qw(); 
 # callback commands
@@ -413,7 +413,7 @@ sub _make_connections_unordered {
 			    
 			    my $fresh_until = $robot_res->fresh_until;
 			    if ($robot_res->is_success) {
-			      my $c = $robot_res->content;
+			      my $c = $content; # thanks to Vlad Ciubotariu
 	                      if ($robot_res->content_type =~ m,^text/, && 
 			          $c =~ /Disallow/) {
 			        LWP::Debug::debug("Parsing robot rules for ". 
@@ -528,7 +528,7 @@ L<LWP::Parallel::UserAgent>, L<LWP::RobotUA>, L<WWW::RobotRules>
 
 =head1 COPYRIGHT
 
-Copyright 1997-2000 Marc Langheinrich E<lt>marclang@cs.washington.edu>
+Copyright 1997-2001 Marc Langheinrich E<lt>marclang@cs.washington.edu>
 
 This library is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
